{% load staticfiles %}
<!DOCTYPE html>
<html lang="en">
<head>
	<title>tsuru web dashboard</title>
	<meta charset="UTF-8" />
	<meta name="description" content="tsuru web dashboard">
	<meta name="viewport" content="width=device-width, initial-scale=1.0" />
	<link rel="stylesheet" href="{% static "css/bootstrap.min.css" %}">
	<link rel="stylesheet" href="{% static "css/abyss.css" %}">
	<link rel="icon" type="image/x-icon" href="{% static "img/favicon.ico" %}">
</head>
<body>
	<div class="container-fluid">
		<div class="row">
			<div class="col-md-9">
				<div class="page-header">
					Opps! Something went wrong.
				</div>
			</div>
		</div>
	</div>
</body>
</html>
