h1 {
  font-family: 'Open Sans';
  font-size: 34px;
  letter-spacing: -1.5px;
  font-weight: bold;
  color: #2e2e2e;
  line-height: 1.2;
}

.events.table {
  font-family: Open Sans;
  font-size: 14px;
  margin-top: 20px;
}

.events tr {
  border-bottom: 2px solid #ddd;
}

.events thead {
  background-color: #ddd;
  color: #333;
  font-weight: bold;
  line-height: 1.1;
}

.events.table th, .events.table td {
  padding: 14px 0 14px 14px;
}

.events tbody tr:hover {
  background-color: #0769de;
  color: #fff;
  cursor: pointer;
}

.events tr:hover .status-success,
.events tr:hover .status-running,
.events tr:hover .status-error,
.events tr:hover .status-canceled {
  color: #fff;
}

.events a {
  color: #2e2e2e;
}

.events .status-success {
  color: #527c2b;
}

.events .status-running {
  color: #333;
}

.events .status-error {
  color: #bc2e1b;
}
