{% extends "base.html" %}

{% block sidebar %}
{% include "sidebar.html" with active="services" %}
{% endblock %}

{% block header %}
<h1>Add service instance for {{ service.name }}</h1>
{% endblock %}

{% block bar %}
<div class="bar">
  <a href="/">dashboard</a> <span class="arrow">></span>
  <a href="{% url 'service-list' %}">services</a> <span class="arrow">></span>
	{{ service.name }}
</div>
{% endblock %}

{% block content %}
<div class="container-fluid">
	<div class="row">
		<div class="col-md-12">
			<form action="" method="post">
				{% csrf_token %}
				<fieldset>
					<div class="control-group">
						<label>Name</label>
						<input type="text" class="input-xlarge" name="name">
						<label>Team</label>
						<select name="team">
							<option></option>
							{% for team in teams %}
							<option value={{ team.name }}>{{ team.name }}</option>
							{% endfor %}
						</select>
                        <label>Plan</label>
                        <select name="plan">
							<option></option>
							{% for plan in plans %}
							<option value={{ plan.Name }}>{{ plan.Name }}</option>
							{% endfor %}
						</select>
                        <label>Description</label>
                        <input type="text" class="input-xlarge" name="description">
					</div>
					<button class="btn primary" type="submit">Add</button>
				</fieldset>
			</form>
		</div>
	</div>
</div>
{% endblock %}
