{% load staticfiles %}
<!DOCTYPE html>
<html lang="en">
<head>
	<title>tsuru web dashboard</title>
	<meta charset="UTF-8" />
	<meta name="viewport" content="width=device-width, initial-scale=1.0" />
	<link rel="stylesheet" href="{% static "css/bootstrap.min.css" %}" />
	<link rel="stylesheet" href="{% static "css/abyss.css" %}" />
	<link rel="stylesheet" href="{% static "css/abyss.login.css" %}" />
	<link rel="icon" type="image/x-icon" href="{% static "img/favicon.ico" %}" />
</head>
<body>
	<div class="container">
		<div class="logo">
			<img src="{% static "img/logo.png" %}" alt="" />
		</div>

		<form class="form-signin" action="" method="post">
			{% csrf_token %}
			<p>Password reset</p>
			{{ form.as_p }}
			<div class="form-actions">
				<span class="pull-right"><input type="submit" class="btn btn-default" value="Submit" /></span>
			</div>
		</form>

	</div> <!-- /container -->
</body>
</html>
